summaryrefslogtreecommitdiffstats
path: root/chrome/common
diff options
context:
space:
mode:
authorxji@chromium.org <xji@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-07-29 18:27:52 +0000
committerxji@chromium.org <xji@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-07-29 18:27:52 +0000
commitde570ef650283a86f90d6179568b49a76df4f1d7 (patch)
tree6eaaa8789d7c7d2297d9269bf576bceafbcb7ce6 /chrome/common
parent84303d8c22c35de5522758bf9b4fab1df15da3d2 (diff)
downloadchromium_src-de570ef650283a86f90d6179568b49a76df4f1d7.zip
chromium_src-de570ef650283a86f90d6179568b49a76df4f1d7.tar.gz
chromium_src-de570ef650283a86f90d6179568b49a76df4f1d7.tar.bz2
This CL fixes issue 17468: Regression: Directionality marks should not be inserted for LTR systems
To avoid empty square displayed around tooltip when system does not have RTL support, only add Unicode marks when element's directionality is not the same as UI's directionality. Note: 1. tooltip will be displayed using its element's directionality. 2. in system without RTL support, tooltip will only be displayed correctly (in its element's directionality and without empty square around) when both UI and element's directionality is LTR. BUG=http://crbug.com/17468 TEST= 1. Uninstall the right-to-left script and east Asian script through the Control Panel and restart system. 2. Run English Chrome. 3. given the following HTML, the displayed tooltip should not have empty square around. <html> <head> <META HTTP-EQUIV="CONTENT-TYPE" CONTENT="TEXT/HTML; CHARSET=utf-8"> </head> <body> <span style="background-color:Blue" title="Hi!">And now here!</span> </body></html> Review URL: http://codereview.chromium.org/160262 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@21975 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common')
-rw-r--r--chrome/common/render_messages_internal.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index ae5e38b..96f25e6 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -1031,8 +1031,9 @@ IPC_BEGIN_MESSAGES(ViewHost)
WebKit::WebScreenInfo /* results */)
// Send the tooltip text for the current mouse position to the browser.
- IPC_MESSAGE_ROUTED1(ViewHostMsg_SetTooltipText,
- std::wstring /* tooltip text string */)
+ IPC_MESSAGE_ROUTED2(ViewHostMsg_SetTooltipText,
+ std::wstring /* tooltip text string */,
+ WebKit::WebTextDirection /* text direction hint */)
// Notification that the text selection has changed.
IPC_MESSAGE_ROUTED1(ViewHostMsg_SelectionChanged,